==> rheolef_6.5.orig.tar.gz: rheolef-6.5/doc/pexamples/transmission.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
SBINDIR="${TOP_SRCDIR}/nfem/sbin"
BINDIR="${TOP_SRCDIR}/nfem/pbin"
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# geo			err_P1	err_P2	err_P3
L="
mkgeo_grid_1d 10	3e-2	1e-2	8e-3
mkgeo_grid_2d 10	5e-2	2e-2	9e-3
mkgeo_grid_3d  4	5e-1	4e-2	3e-2
"

geo="tmp.geo"

while test "$L" != ""; do

  mkgeo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  n=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  run "${SBINDIR}/$mkgeo $n -region -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > $geo 2>/dev/null"
  if test $? -ne 0; then status=1; fi

  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./transmission $geo $Pk 2>/dev/null | ./transmission_error $err 2>/dev/null >/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

run "rm -f $geo"

exit $status

==> rheolef_6.7.orig.tar.gz: rheolef-6.7/doc/pexamples/transmission.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
SBINDIR="../../nfem/sbin"
BINDIR="../../nfem/pbin"
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

# geo			err_P1	err_P2	err_P3
L="
mkgeo_grid_1d 10	3e-2	1e-2	8e-3
mkgeo_grid_2d 10	5e-2	2e-2	9e-3
mkgeo_grid_3d  4	5e-1	4e-2	3e-2
"

geo="tmp.geo"

while test "$L" != ""; do

  mkgeo=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  n=`echo $L | awk '{print $1}'`
  L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
  run "${SBINDIR}/$mkgeo $n -region -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > $geo 2>/dev/null"
  if test $? -ne 0; then status=1; fi

  for Pk in P1 P2 P3; do
    err=`echo $L | awk '{print $1}'`
    L=`echo $L | awk '{for (i=2; i <= NF; i++) print $i}'`
    loop_mpirun "./transmission $geo $Pk 2>/dev/null | ./transmission_error $err 2>/dev/null >/dev/null"
    if test $? -ne 0; then status=1; fi
  done
done

run "rm -f $geo"

exit $status
